<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 * @return array An array of default values
 */

function tale_travel_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$tale_travel_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#ff8737',
		'header_tagline_color'			=> '#888',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff8737',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_author_enable'				=> true,
		'header_layout'					=> 'center-aligned',

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'          	 	=> esc_html__( 'Read More', 'tale-travel-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'tale-travel-pro' ), '[the-year]', '[site-link]' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'tale-travel-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Featured,Top Stories,Popular Trips,Trending,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'tale-travel-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'page',

		// featured
		'featured_section_enable'		=> true,
		'featured_subscribe_enable'		=> false,
		'featured_content_type'			=> 'category',
		'featured_subscribe_title'		=> esc_html__( 'Subscribe to our newsletter and be up to date of our latest articles, activities.', 'tale-travel-pro' ),
		'featured_subscribe_btn_title'	=> esc_html__( 'Join Us', 'tale-travel-pro' ),

		// top stories
		'top_stories_section_enable'	=> true,
		'top_stories_content_type'		=> 'category',
		'top_stories_count'				=> 3,
		'top_stories_column'			=> 'col-3',
		'top_stories_title'				=> esc_html__( 'Top Stories', 'tale-travel-pro' ),
		'top_stories_btn_title'			=> esc_html__( 'View All Stories', 'tale-travel-pro' ),

		// popular trips
		'popular_trips_section_enable'	=> true,
		'popular_trips_content_type'	=> 'category',
		'popular_trips_count'			=> 3,
		'popular_trips_column'			=> 'col-3',
		'popular_trips_title'			=> esc_html__( 'Popular Trips', 'tale-travel-pro' ),
		'popular_trips_btn_title'		=> esc_html__( 'View All Popular Trips', 'tale-travel-pro' ),

		// trending
		'trending_section_enable'		=> true,
		'trending_content_type'			=> 'category',
		'trending_count'				=> 4,
		'trending_column'				=> 'col-4',
		'trending_title'				=> esc_html__( 'Trending Now', 'tale-travel-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 6,
		'blog_column'					=> 'col-6',
		'blog_title'					=> esc_html__( 'Latest Blog', 'tale-travel-pro' ),

	);

	$output = apply_filters( 'tale_travel_pro_default_theme_options', $tale_travel_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}