<?php
/**
 * Trending Section options
 *
 * @package Theme Palace
 * @subpackage Tale Travel Pro
 * @since Tale Travel Pro 1.0.0
 */

// Add Trending section
$wp_customize->add_section( 'tale_travel_pro_trending_section', array(
	'title'             => esc_html__( 'Trending','tale-travel-pro' ),
	'description'       => esc_html__( 'Trending Section options.', 'tale-travel-pro' ),
	'panel'             => 'tale_travel_pro_front_page_panel',
) );

// Trending content enable control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_section_enable]', array(
	'default'			=> 	$options['trending_section_enable'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tale_Travel_Pro_Switch_Control( $wp_customize, 'tale_travel_pro_theme_options[trending_section_enable]', array(
	'label'             => esc_html__( 'Trending Section Enable', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'on_off_label' 		=> tale_travel_pro_switch_options(),
) ) );

// popular destination title setting and control
$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_title]', array(
	'default'			=> $options['trending_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[trending_title]', array(
	'label'           	=> esc_html__( 'Title', 'tale-travel-pro' ),
	'section'        	=> 'tale_travel_pro_trending_section',
	'active_callback' 	=> 'tale_travel_pro_is_trending_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tale_travel_pro_theme_options[trending_title]', array(
		'selector'            => '#trending-posts .section-header h2.section-title',
		'settings'            => 'tale_travel_pro_theme_options[trending_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tale_travel_pro_trending_title_partial',
    ) );
}

// Trending column type control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_column]', array(
	'default'          	=> $options['trending_column'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[trending_column]', array(
	'label'             => esc_html__( 'Column Layout', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tale_travel_pro_is_trending_section_enable',
	'choices'			=> array(
		'col-2'	=> esc_html__( 'Column Two', 'tale-travel-pro' ),
		'col-3'	=> esc_html__( 'Column Three', 'tale-travel-pro' ),
		'col-4'	=> esc_html__( 'Column Four', 'tale-travel-pro' ),
		),
) );

// Trending content type control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_content_type]', array(
	'default'          	=> $options['trending_content_type'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[trending_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tale_travel_pro_is_trending_section_enable',
	'choices'			=> tale_travel_pro_trending_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_count]', array(
	'default'          	=> $options['trending_count'],
	'sanitize_callback' => 'tale_travel_pro_sanitize_number_range',
	'validate_callback' => 'tale_travel_pro_validate_trending_count',
) );

$wp_customize->add_control( 'tale_travel_pro_theme_options[trending_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'tale-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'active_callback'   => 'tale_travel_pro_is_trending_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i=1; $i <= $options['trending_count']; $i++ ) { 
	// trending pages drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[trending_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_trending_section',
		'choices'			=> tale_travel_pro_page_choices(),
		'active_callback'	=> 'tale_travel_pro_is_trending_section_content_page_enable',
	) ) );

	// trending posts drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[trending_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_trending_section',
		'choices'			=> tale_travel_pro_post_choices(),
		'active_callback'	=> 'tale_travel_pro_is_trending_section_content_post_enable',
	) ) );

	// trending trips drop down chooser control and setting
	$wp_customize->add_setting( 'tale_travel_pro_theme_options[trending_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tale_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Chooser( $wp_customize, 'tale_travel_pro_theme_options[trending_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tale-travel-pro' ), $i ),
		'section'           => 'tale_travel_pro_trending_section',
		'choices'			=> tale_travel_pro_trip_choices(),
		'active_callback'	=> 'tale_travel_pro_is_trending_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[trending_content_category]', array(
	'sanitize_callback' => 'tale_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[trending_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tale-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Trending selected no of posts will be shown from selected category', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_trending_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[trending_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[trending_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_trending_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[trending_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[trending_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_trending_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tale_travel_pro_theme_options[trending_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tale_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tale_travel_pro_theme_options[trending_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'tale-travel-pro' ),
	'section'           => 'tale_travel_pro_trending_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tale_travel_pro_is_trending_section_content_destination_enable'
) ) );

